from setuptools import setup

setup(name='snddistributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions'],
      author='kushagra',
      author_email='kushagrarastogiies@gmail.com',
      zip_safe=False)
